@@ -9,7 +9,7 @@ import (
 	"github.com/mattn/go-runewidth"
 )
 
-func init() { //nolint:gochecknoinits
+func init() {
 	runewidth.DefaultCondition.EastAsianWidth = false
 }
 
@@ -114,6 +114,10 @@ type Writer struct {
 	hyperlinkStart  string
 	hyperlinkCenter string
 	hyperlinkEnd    string
+
+	iTermPromptMark string
+	iTermCurrentDir string
+	iTermRemoteHost string
 }
 
 func (w *Writer) Init(shellName string) {
@@ -137,6 +141,9 @@ func (w *Writer) Init(shellName string) {
 		w.osc99 = "\\[\x1b]9;9;%s\x1b\\\\\\]"
 		w.osc7 = "\\[\x1b]7;file://%s/%s\x1b\\\\\\]"
 		w.osc51 = "\\[\x1b]51;A;%s@%s:%s\x1b\\\\\\]"
+		w.iTermPromptMark = "\\[$(iterm2_prompt_mark)\\]"
+		w.iTermCurrentDir = "\\[\x1b]1337;CurrentDir=%s\x07\\]"
+		w.iTermRemoteHost = "\\[\x1b]1337;RemoteHost=%s@%s\x07\\]"
 	case shell.ZSH, shell.TCSH:
 		w.format = "%%{%s%%}"
 		w.linechange = "%%{\x1b[%d%s%%}"
@@ -154,6 +161,9 @@ func (w *Writer) Init(shellName string) {
 		w.osc99 = "%%{\x1b]9;9;%s\x1b\\%%}"
 		w.osc7 = "%%{\x1b]7;file://%s/%s\x1b\\%%}"
 		w.osc51 = "%%{\x1b]51;A%s@%s:%s\x1b\\%%}"
+		w.iTermPromptMark = "%{$(iterm2_prompt_mark)%}"
+		w.iTermCurrentDir = "%%{\x1b]1337;CurrentDir=%s\x07%%}"
+		w.iTermRemoteHost = "%%{\x1b]1337;RemoteHost=%s@%s\x07%%}"
 	default:
 		w.linechange = "\x1b[%d%s"
 		w.left = "\x1b[%dD"
@@ -171,6 +181,9 @@ func (w *Writer) Init(shellName string) {
 		w.osc99 = "\x1b]9;9;%s\x1b\\"
 		w.osc7 = "\x1b]7;file://%s/%s\x1b\\"
 		w.osc51 = "\x1b]51;A%s@%s:%s\x1b\\"
+		w.iTermPromptMark = "$(iterm2_prompt_mark)"
+		w.iTermCurrentDir = "\x1b]1337;CurrentDir=%s\x07"
+		w.iTermRemoteHost = "\x1b]1337;RemoteHost=%s@%s\x07"
 	}
 }
 
